jQuery(document).ready(function($) {
    const form = $('#lottery-picker-form');
    const mainSection = {
        fileInput: $('#csv_file'),
        columnSelector: $('#column-selector'),
        columnSelect: $('#selected_column'),
        tempFile: null
    };
    const previousSection = {
        fileInput: $('#previous_csv'),
        columnSelector: $('#previous-column-selector'),
        columnSelect: $('#previous_selected_column'),
        tempFile: null
    };
    const runLotteryBtn = $('#run-lottery');
    const lotteryAnimation = $('#lottery-animation');
    const lotteryResults = $('#lottery-results');
    const viewWinnersPost = $('#view-winners-post');

    // Debug initial state
    console.log('Lottery Picker: Initializing...', {
        mainSection: {
            fileInput: mainSection.fileInput.length,
            columnSelector: mainSection.columnSelector.length,
            columnSelect: mainSection.columnSelect.length
        },
        previousSection: {
            fileInput: previousSection.fileInput.length,
            columnSelector: previousSection.columnSelector.length,
            columnSelect: previousSection.columnSelect.length
        }
    });

    // Direct event binding for file inputs
    $('#csv_file, #previous_csv').on('change', function(e) {
        const isOptional = this.id === 'previous_csv';
        const section = isOptional ? previousSection : mainSection;
        
        console.log('File input changed:', {
            inputId: this.id,
            isOptional: isOptional,
            hasFiles: this.files.length > 0
        });
        
        if (this.files.length > 0) {
            processFile(this.files[0], section, isOptional);
        }
    });

    function processFile(file, section, isOptional) {
        console.log('Processing file:', {
            name: file.name,
            size: file.size,
            type: file.type,
            isOptional: isOptional,
            isMultisite: lotteryPickerAdmin.is_multisite
        });

        const formData = new FormData();
        formData.append('action', 'process_csv_upload');
        formData.append('nonce', lotteryPickerAdmin.nonce);
        formData.append('csv_file', file);
        formData.append('is_optional', isOptional ? '1' : '0');

        // Show loading state
        const loadingMessage = $('<div class="notice notice-info"><p>Processing CSV file...</p></div>');
        form.prepend(loadingMessage);

        // Always use the main AJAX URL for both files
        const ajaxUrl = lotteryPickerAdmin.ajaxurl;
        
        console.log('Using AJAX URL:', {
            url: ajaxUrl,
            isOptional: isOptional,
            isMultisite: lotteryPickerAdmin.is_multisite
        });

        // Make the AJAX request
        $.ajax({
            url: ajaxUrl,
            type: 'POST',
            data: formData,
            processData: false,
            contentType: false,
            success: function(response) {
                console.log('AJAX response:', response);
                loadingMessage.remove();

                if (response.success && response.data && Array.isArray(response.data.columns)) {
                    createColumnButtons(section, response.data.columns, response.data.temp_file, isOptional);
                } else {
                    const errorMsg = response.data || 'Unknown error';
                    console.error('CSV processing error:', errorMsg);
                    showError('Error processing CSV file: ' + errorMsg);
                    // Reset file input on error
                    section.fileInput.val('');
                }
            },
            error: function(xhr, status, error) {
                console.error('AJAX error details:', {
                    status: status,
                    error: error,
                    response: xhr.responseText,
                    state: xhr.state(),
                    statusCode: xhr.status,
                    statusText: xhr.statusText
                });
                loadingMessage.remove();
                showError('Error uploading file: ' + (xhr.responseText || error || 'Unknown error'));
                // Reset file input on error
                section.fileInput.val('');
            }
        });
    }

    function createColumnButtons(section, columns, tempFile, isOptional) {
        // Store the temp file
        section.tempFile = tempFile;

        // Clear existing buttons
        const buttonContainer = section.columnSelector.find('.column-buttons');
        buttonContainer.empty();

        console.log('Creating buttons:', {
            sectionId: section.columnSelector.attr('id'),
            columns: columns,
            containerExists: buttonContainer.length > 0,
            isOptional: isOptional
        });

        // Create buttons for each column
        columns.forEach((column, index) => {
            const button = $('<button>', {
                type: 'button',
                class: 'wp-core-ui button column-button',
                text: column,
                'data-index': index
            }).on('click', function(e) {
                e.preventDefault();
                e.stopPropagation();
                
                // Update button states
                buttonContainer.find('.column-button').removeClass('button-primary selected');
                $(this).addClass('button-primary selected');
                
                // Update hidden input
                section.columnSelect.val(index);
                
                // Update run button state
                updateRunButton();
                
                console.log('Column selected:', {
                    column: column,
                    index: index,
                    isOptional: isOptional,
                    sectionId: section.columnSelector.attr('id')
                });
            });
            
            buttonContainer.append(button);
        });

        // Show the column selector
        section.columnSelector.removeClass('hidden').show();
        
        console.log('Buttons created:', {
            sectionId: section.columnSelector.attr('id'),
            buttonCount: buttonContainer.find('button').length,
            isVisible: section.columnSelector.is(':visible'),
            isOptional: isOptional
        });
    }

    function showError(message) {
        const errorMessage = $('<div class="notice notice-error"><p>' + message + '</p></div>');
        form.prepend(errorMessage);
        setTimeout(() => errorMessage.fadeOut(() => errorMessage.remove()), 5000);
    }

    function updateRunButton() {
        const mainColumnSelected = mainSection.columnSelect.val() !== '';
        const previousFileSelected = previousSection.fileInput[0].files.length > 0;
        const previousColumnSelected = previousSection.columnSelect.val() !== '';
        
        console.log('Run button state:', {
            mainColumnSelected,
            previousFileSelected,
            previousColumnSelected
        });

        const shouldEnable = mainColumnSelected && (!previousFileSelected || previousColumnSelected);
        runLotteryBtn.toggle(shouldEnable).prop('disabled', !shouldEnable);
    }

    // Handle form submission
    form.on('submit', function(e) {
        e.preventDefault();

        const formData = {
            action: 'run_lottery',
            nonce: lotteryPickerAdmin.nonce,
            lottery_name: $('#lottery_name').val(),
            num_winners: $('#num_winners').val(),
            selected_column: mainSection.columnSelect.val(),
            csv_file: mainSection.tempFile
        };

        // Only add previous CSV data if a file was uploaded and column selected
        if (previousSection.fileInput[0].files.length > 0 && previousSection.columnSelect.val() !== '') {
            formData.previous_csv_file = previousSection.tempFile;
            formData.previous_selected_column = previousSection.columnSelect.val();
        }

        // Start animation
        form.hide();
        lotteryAnimation.show();
        startLotteryAnimation();

        $.ajax({
            url: lotteryPickerAdmin.ajaxurl,
            type: 'POST',
            data: formData,
            success: function(response) {
                if (response.success) {
                    setTimeout(function() {
                        stopLotteryAnimation();
                        displayResults(response.data);
                    }, 3000);
                } else {
                    stopLotteryAnimation();
                    alert('Error running lottery: ' + response.data);
                    form.show();
                }
            },
            error: function() {
                stopLotteryAnimation();
                alert('Error running lottery. Please try again.');
                form.show();
            }
        });
    });

    function startLotteryAnimation() {
        if (typeof LotteryAnimation !== 'undefined') {
            LotteryAnimation.start();
        }
    }

    function stopLotteryAnimation() {
        lotteryAnimation.hide();
        if (typeof LotteryAnimation !== 'undefined') {
            LotteryAnimation.stop();
        }
    }

    function displayResults(data) {
        const resultsContainer = lotteryResults.find('.results-container');
        
        // Display total entries with breakdown
        const entriesText = `Total Entries: ${data.total_entries} ` +
            `(${data.main_entries} from main list${data.previous_entries ? ` + ${data.previous_entries} from previous non-winners` : ''})`;
        resultsContainer.find('.total-entries').text(entriesText);
        
        const winnersList = resultsContainer.find('.winners-list');
        winnersList.empty();
        winnersList.append('<h3>Winners:</h3>');
        const winnerItems = $('<ol>');
        data.winners.forEach(function(winner) {
            winnerItems.append($('<li>').text(winner));
        });
        winnersList.append(winnerItems);
        
        resultsContainer.find('.draw-date').text('Draw Date: ' + new Date().toLocaleString());

        // Add non-winners CSV download link
        if (data.non_winners_csv) {
            const downloadLink = $('<div class="non-winners-download"></div>').html(
                '<p><strong>Download remaining entries:</strong></p>' +
                '<a href="' + data.non_winners_csv + '" class="button button-secondary" download>' +
                '<span class="dashicons dashicons-download"></span> Download Non-Winners CSV</a>'
            );
            winnersList.after(downloadLink);
        }
        
        viewWinnersPost.attr('href', `post.php?post=${data.post_id}&action=edit`).show();
        lotteryResults.show();
    }
}); 